==> ejc-analyticdatas-api-3.0.0-20240511.081316-48-sources.jar: com/ejianc/foundation/analyticdatas/vo/BehaviorDataAnalyticVO.java <==
package com.ejianc.foundation.analyticdatas.vo;

import java.util.Date;
import java.util.List;

import com.ejianc.framework.skeleton.template.BaseVO;

public class BehaviorDataAnalyticVO extends BaseVO {

	private static final long serialVersionUID = 1L;

	private String deviceId; // 访问设备

	private String province; // 省

	private String city; // 市

	private String operators; // 运营商

	private String ipAddr; // ip地址

	private String userId; // 用户ID

	private String companyName; // 用户公司

	private String companyType; // 用户公司类型 对应企业类型

	private String userName; // 用户姓名

	private String userCode; // 用户账号

	private String userMobile; // 用户手机号

	private String appId; // 应用ID

	private String appName; // 应用名称

	private String eventCode; // 事件code

	private Date operateTime; // 操作时间

	private String statistics; // 统计次数（地图使用）

	private Long comNums;// 某应用下使用的组织数量

	private List<String> comNames;// 某应用下使用的组织

	private String reqFrom;

	private Long operateOrgId; // 操作组织

	private String operateOrgName; // 操作组织名称

	public Long getComNums() {
		return comNums;
	}

	public void setComNums(Long comNums) {
		this.comNums = comNums;
	}

	public List<String> getComNames() {
		return comNames;
	}

	public void setComNames(List<String> comNames) {
		this.comNames = comNames;
	}

	public String getDeviceId() {
		return deviceId;
	}

	public void setDeviceId(String deviceId) {
		this.deviceId = deviceId;
	}

	public String getProvince() {
		return province;
	}

	public void setProvince(String province) {
		this.province = province;
	}

	public String getCity() {
		return city;
	}

	public void setCity(String city) {
		this.city = city;
	}

	public String getOperators() {
		return operators;
	}

	public void setOperators(String operators) {
		this.operators = operators;
	}

	public String getIpAddr() {
		return ipAddr;
	}

	public void setIpAddr(String ipAddr) {
		this.ipAddr = ipAddr;
	}

	public String getUserId() {
		return userId;
	}

	public void setUserId(String userId) {
		this.userId = userId;
	}

	public String getCompanyName() {
		return companyName;
	}

	public void setCompanyName(String companyName) {
		this.companyName = companyName;
	}

	public String getUserName() {
		return userName;
	}

	public void setUserName(String userName) {
		this.userName = userName;
	}

	public String getUserCode() {
		return userCode;
	}

	public void setUserCode(String userCode) {
		this.userCode = userCode;
	}

	public String getUserMobile() {
		return userMobile;
	}

	public void setUserMobile(String userMobile) {
		this.userMobile = userMobile;
	}

	public String getAppId() {
		return appId;
	}

	public void setAppId(String appId) {
		this.appId = appId;
	}

	public String getAppName() {
		return appName;
	}

	public void setAppName(String appName) {
		this.appName = appName;
	}

	public String getEventCode() {
		return eventCode;
	}

	public void setEventCode(String eventCode) {
		this.eventCode = eventCode;
	}

	public Date getOperateTime() {
		return operateTime;
	}

	public void setOperateTime(Date operateTime) {
		this.operateTime = operateTime;
	}

	public String getStatistics() {
		return statistics;
	}

	public void setStatistics(String statistics) {
		this.statistics = statistics;
	}

	public String getCompanyType() {
		return companyType;
	}

	public void setCompanyType(String companyType) {
		this.companyType = companyType;
	}

	public String getReqFrom() {
		return reqFrom;
	}

	public void setReqFrom(String reqFrom) {
		this.reqFrom = reqFrom;
	}

	public Long getOperateOrgId() {
		return operateOrgId;
	}

	public void setOperateOrgId(Long operateOrgId) {
		this.operateOrgId = operateOrgId;
	}

	public String getOperateOrgName() {
		return operateOrgName;
	}

	public void setOperateOrgName(String operateOrgName) {
		this.operateOrgName = operateOrgName;
	}
}

==> ejc-analyticdatas-api-3.0.0-20240529.105337-66-sources.jar: com/ejianc/foundation/analyticdatas/vo/BehaviorDataAnalyticVO.java <==
package com.ejianc.foundation.analyticdatas.vo;

import java.util.Date;
import java.util.List;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

public class BehaviorDataAnalyticVO extends BaseVO {

	private static final long serialVersionUID = 1L;

	private String deviceId; // 访问设备

	private String province; // 省

	private String city; // 市

	private String operators; // 运营商

	private String ipAddr; // ip地址

	private String userId; // 用户ID

	private String companyName; // 用户公司

	private String companyType; // 用户公司类型 对应企业类型

	private String userName; // 用户姓名

	private String userCode; // 用户账号

	private String userMobile; // 用户手机号

	private String appId; // 应用ID

	private String appName; // 应用名称

	private String eventCode; // 事件code

	private Date operateTime; // 操作时间

	private String statistics; // 统计次数（地图使用）

	private Long comNums;// 某应用下使用的组织数量

	private List<String> comNames;// 某应用下使用的组织

	private String reqFrom;

	private Long operateOrgId; // 操作组织

	private String operateOrgName; // 操作组织名称

	private String operateOrgCode;

	private Integer operateOrgType;

	private Long departmentId;

	private String departmentName;

	/**
	 * 员工ID
	 */
	private Long employeeId;

	/**
	 * 员工姓名
	 */
	private String employeeName;

	private Long orgId;

	private String orgName;

	public Long getComNums() {
		return comNums;
	}

	public void setComNums(Long comNums) {
		this.comNums = comNums;
	}

	public List<String> getComNames() {
		return comNames;
	}

	public void setComNames(List<String> comNames) {
		this.comNames = comNames;
	}

	public String getDeviceId() {
		return deviceId;
	}

	public void setDeviceId(String deviceId) {
		this.deviceId = deviceId;
	}

	public String getProvince() {
		return province;
	}

	public void setProvince(String province) {
		this.province = province;
	}

	public String getCity() {
		return city;
	}

	public void setCity(String city) {
		this.city = city;
	}

	public String getOperators() {
		return operators;
	}

	public void setOperators(String operators) {
		this.operators = operators;
	}

	public String getIpAddr() {
		return ipAddr;
	}

	public void setIpAddr(String ipAddr) {
		this.ipAddr = ipAddr;
	}

	public String getUserId() {
		return userId;
	}

	public void setUserId(String userId) {
		this.userId = userId;
	}

	public String getCompanyName() {
		return companyName;
	}

	public void setCompanyName(String companyName) {
		this.companyName = companyName;
	}

	public String getUserName() {
		return userName;
	}

	public void setUserName(String userName) {
		this.userName = userName;
	}

	public String getUserCode() {
		return userCode;
	}

	public void setUserCode(String userCode) {
		this.userCode = userCode;
	}

	public String getUserMobile() {
		return userMobile;
	}

	public void setUserMobile(String userMobile) {
		this.userMobile = userMobile;
	}

	public String getAppId() {
		return appId;
	}

	public void setAppId(String appId) {
		this.appId = appId;
	}

	public String getAppName() {
		return appName;
	}

	public void setAppName(String appName) {
		this.appName = appName;
	}

	public String getEventCode() {
		return eventCode;
	}

	public void setEventCode(String eventCode) {
		this.eventCode = eventCode;
	}

	public Date getOperateTime() {
		return operateTime;
	}

	public void setOperateTime(Date operateTime) {
		this.operateTime = operateTime;
	}

	public String getStatistics() {
		return statistics;
	}

	public void setStatistics(String statistics) {
		this.statistics = statistics;
	}

	public String getCompanyType() {
		return companyType;
	}

	public void setCompanyType(String companyType) {
		this.companyType = companyType;
	}

	public String getReqFrom() {
		return reqFrom;
	}

	public void setReqFrom(String reqFrom) {
		this.reqFrom = reqFrom;
	}

	public Long getOperateOrgId() {
		return operateOrgId;
	}

	public void setOperateOrgId(Long operateOrgId) {
		this.operateOrgId = operateOrgId;
	}

	public String getOperateOrgName() {
		return operateOrgName;
	}

	public void setOperateOrgName(String operateOrgName) {
		this.operateOrgName = operateOrgName;
	}

	public String getOperateOrgCode() {
		return operateOrgCode;
	}

	public void setOperateOrgCode(String operateOrgCode) {
		this.operateOrgCode = operateOrgCode;
	}

	public Long getDepartmentId() {
		return departmentId;
	}

	public void setDepartmentId(Long departmentId) {
		this.departmentId = departmentId;
	}

	public String getDepartmentName() {
		return departmentName;
	}

	public void setDepartmentName(String departmentName) {
		this.departmentName = departmentName;
	}

	public Integer getOperateOrgType() {
		return operateOrgType;
	}

	public void setOperateOrgType(Integer operateOrgType) {
		this.operateOrgType = operateOrgType;
	}

	public Long getEmployeeId() {
		return employeeId;
	}

	public void setEmployeeId(Long employeeId) {
		this.employeeId = employeeId;
	}

	public String getEmployeeName() {
		return employeeName;
	}

	public void setEmployeeName(String employeeName) {
		this.employeeName = employeeName;
	}
	@ReferSerialTransfer(referCode="idm-org")
	public Long getOrgId() {
		return orgId;
	}
	@ReferDeserialTransfer
	public void setOrgId(Long orgId) {
		this.orgId = orgId;
	}

	public String getOrgName() {
		return orgName;
	}

	public void setOrgName(String orgName) {
		this.orgName = orgName;
	}
}
